@@ -195,3 +195,11 @@ stopifnot(pvalue(it) == 0.1)
 itMC <- independence_test(x ~ g, distribution = approximate(99999))
 ci <- attr(pvalue(itMC), "conf.int")
 stopifnot(ci[1] < pvalue(it) && ci[2] > pvalue(it))
+
+### any() not applied to logicals
+### spotted by R-2.7.0 and Kaspar Daniel Hansen
+x <- c(1.83,  0.50,  1.62,  2.48, 1.68, 1.88, 1.55, 3.06, 1.30)
+y <- c(0.878, 0.647, 0.598, 2.05, 1.06, 1.29, 1.06, 3.14, 1.29)
+### must not give a warning
+wilcoxsign_test(x ~ y, alternative = "greater", 
+                distribution = exact())
